==> webgui_7.9.18.orig.tar.gz: WebGUI/lib/WebGUI/i18n/Dutch/Asset_Template.pm <==
package WebGUI::i18n::Dutch::Asset_Template;
use utf8;
our $I18N = {
  'Already attached!' => {
    'lastUpdated' => '1258548972',
    'message' => 'Dit staat al in de bijlage!'
  },
  'No url!' => {
    'lastUpdated' => '1258535779',
    'message' => 'Geen URL!'
  },
  'assetName' => {
    'lastUpdated' => '1151504830',
    'message' => 'Sjabloon'
  },
  'attachment add button' => {
    'lastUpdated' => '1242729886',
    'message' => 'Toevoegen'
  },
  'attachment add field label' => {
    'lastUpdated' => '1242729965',
    'message' => 'Voeg bijlage(n) toe'
  },
  'attachment display label' => {
    'lastUpdated' => '1242729982',
    'message' => 'Bijlagen'
  },
  'attachment header index' => {
    'lastUpdated' => '1242730032',
    'message' => 'Reeksnummer'
  },
  'attachment header remove' => {
    'lastUpdated' => '1242730016',
    'message' => 'Verwijderen'
  },
  'attachment header type' => {
    'lastUpdated' => '1242730050',
    'message' => 'Type'
  },
  'attachment header url' => {
    'lastUpdated' => '1242730065',
    'message' => 'Url'
  },
  'body background color' => {
    'lastUpdated' => '1151506164',
    'message' => 'Achtergrondkleur body'
  },
  'body background color description' => {
    'lastUpdated' => '1207839342',
    'message' => 'De achtergrondkleur voor het body-gedeelte van de pagina.'
  },
  'body content' => {
    'lastUpdated' => '1151504950',
    'message' => 'Hier komt de content.'
  },
  'body text color' => {
    'lastUpdated' => '1151506183',
    'message' => 'Tekstkleur body'
  },
  'body text color description' => {
    'lastUpdated' => '1151652284',
    'message' => 'De kleur van de tekst in het body gedeelte.'
  },
  'choose a layout' => {
    'lastUpdated' => '1151506201',
    'message' => 'Kies een vormgeving voor deze stijl:'
  },
  'css label' => {
    'lastUpdated' => '1242730103',
    'message' => 'CSS Stylesheet'
  },
  'default parser' => {
    'lastUpdated' => '1166198514',
    'message' => 'Standaard parser'
  },
  'edit template' => {
    'lastUpdated' => '1151506214',
    'message' => 'Wijzigen sjabloon'
  },
  'field storageIdExample' => {
    'lastUpdated' => '1273488800',
    'message' => 'Voorbeeldafbeelding'
  },
  'field storageIdExample description' => {
    'lastUpdated' => '1273488844',
    'message' => 'Een voorbeeldafbeelding die toont hoe het sjabloon eruit ziet voordat het geselecteerd wordt door de gebruiker.'
  },
  'head block' => {
    'lastUpdated' => '1151654999',
    'message' => 'HEAD blok'
  },
  'head block description' => {
    'lastUpdated' => '1151655344',
    'message' => 'HEAD gedeelte van het HTML document. Hier komen de meta tags, style sheets, etc.'
  },
  'header background color' => {
    'lastUpdated' => '1151655022',
    'message' => 'Achtergrondkleur header'
  },
  'header background color description' => {
    'lastUpdated' => '1151655122',
    'message' => 'De achtergrondkleur van de header (het bovenste gedeelte) van de pagina.'
  },
  'header text color' => {
    'lastUpdated' => '1151655031',
    'message' => 'Tekstkleur header'
  },
  'header text color description' => {
    'lastUpdated' => '1151655131',
    'message' => 'De tekstkleur voor de header (het bovenste gedeelte) van de pagina.'
  },
  'heading' => {
    'lastUpdated' => '1151655169',
    'message' => 'Header'
  },
  'js body label' => {
    'lastUpdated' => '1242730148',
    'message' => 'Javascript (wordt ingevoegd net voor het </body> element)'
  },
  'js head label' => {
    'lastUpdated' => '1242730177',
    'message' => 'Javascript (wordt toegevoegd in de <head> sectie)'
  },
  'link color' => {
    'lastUpdated' => '1151505939',
    'message' => 'Link kleur'
  },
  'link color description' => {
    'lastUpdated' => '1151505973',
    'message' => 'De kleur van de links op de pagina. De standaardkleur is blauw.'
  },
  'logo' => {
    'lastUpdated' => '1151505728',
    'message' => 'Logo'
  },
  'logo description' => {
    'lastUpdated' => '1151505885',
    'message' => 'Dit veld kan gebruikt worden om een logo te uploaden. Het logo moet minder dan 200 pixels breed en minder dan 100 pixels hoog zijn.'
  },
  'logo subtext' => {
    'lastUpdated' => '1151505879',
    'message' => 'Het logo moet minder dan 200 pixels breed en minder dan 100 pixels hoog zijn.'
  },
  'make duplicate label' => {
    'lastUpdated' => '1222876939',
    'message' => 'Dupliceer dit sjabloon en bewerk'
  },
  'menu' => {
    'lastUpdated' => '1151505891',
    'message' => 'Menu'
  },
  'menu background color' => {
    'lastUpdated' => '1151505899',
    'message' => 'Achtergrondkleur menu'
  },
  'menu background color description' => {
    'lastUpdated' => '1208527745',
    'message' => 'De achtergrondkleur van het menu-gedeelte van de pagina.'
  },
  'namespace' => {
    'lastUpdated' => '1151506117',
    'message' => 'Namespace'
  },
  'namespace description' => {
    'lastUpdated' => '1151655217',
    'message' => 'Wat voor type sjabloon is dit?'
  },
  'page background color' => {
    'lastUpdated' => '1151506141',
    'message' => 'Achtergrondkleur pagina'
  },
  'page background color description' => {
    'lastUpdated' => '1151652299',
    'message' => 'De achtergrondkleur van de hele pagina.'
  },
  'parser' => {
    'lastUpdated' => '1151652326',
    'message' => 'Sjabloon type'
  },
  'parser description' => {
    'lastUpdated' => '1222349702',
    'message' => 'Wanneer in de configuratie meerdere mogelijke sjabloon engines zijn opgeven kunt u hier kiezen naar welke engines deze sjabloon moet worden gestuurd.'
  },
  'plugin enabled header' => {
    'lastUpdated' => '1166198534',
    'message' => 'Ingeschakeld?'
  },
  'plugin name' => {
    'lastUpdated' => '1166198541',
    'message' => 'Parser naam'
  },
  'session form variables' => {
    'lastUpdated' => '1151655244',
    'message' => '<p><strong>Sessie form variabelen</strong><br />Alle form variabelen zijn beschikbaar in het sjabloon m.b.v. de volgende syntax:<br />&lt;tmpl_var session.form.<em>variabele</em>&gt;<br />Indien de form&nbsp;variabele meer dan 1 waarde bevat zal enkel de laatste waarde worden doorgegeven.</p>'
  },
  'session scratch variables' => {
    'lastUpdated' => '1166204198',
    'message' => '<b>Sessie Scratch Variabelen</b><BR>
Alle scratchvariabelen zullen aanwezig zijn in het template volgens deze syntax:<BR>
&lt;tmpl_var session.scratch.<i>variabel</i>&gt;'
  },
  'session.config.extrasurl' => {
    'lastUpdated' => '1151505688',
    'message' => 'De URL van de extras directory uit de WebGUI configuratie.'
  },
  'session.setting.anonymousRegistration' => {
    'lastUpdated' => '1207830048',
    'message' => 'Mag een anonieme gebruiker wel of niet zich registreren op de site (uit de WebGUI instellingen).'
  },
  'session.setting.companyName' => {
    'lastUpdated' => '1151505612',
    'message' => 'De bedrijfsnaam uit de WebGUI instellingen.'
  },
  'session.user.firstDayOfWeek' => {
    'lastUpdated' => '1151505503',
    'message' => 'De eerste dag van de week zoals ingesteld in het gebruikersprofiel van de huidige gebruiker.'
  },
  'session.user.username' => {
    'lastUpdated' => '1207839306',
    'message' => 'De gebruikersnaam van de huidige gebruiker.'
  },
  'session.var.adminOn' => {
    'lastUpdated' => '1151505456',
    'message' => 'Deze variabele is waar indien de gebruiker in Admin mode is.'
  },
  'show in forms' => {
    'lastUpdated' => '1151505371',
    'message' => 'Zichtbaar in formulieren?'
  },
  'show in forms description' => {
    'lastUpdated' => '1168959904',
    'message' => 'Moet dit sjabloon zichtbaar zijn in de lijst van sjablonen uit deze namespace?'
  },
  'site name' => {
    'lastUpdated' => '1151504975',
    'message' => 'Sitenaam'
  },
  'site name description' => {
    'lastUpdated' => '1151504988',
    'message' => 'De naam van de website'
  },
  'style wizard' => {
    'lastUpdated' => '1151650653',
    'message' => 'Style&nbsp;wizard'
  },
  'template description' => {
    'lastUpdated' => '1151505077',
    'message' => 'Maak een sjabloon met behulp van sjabloon commando\'s, variabelen, macro\'s en HTML.'
  },
  'template error' => {
    'lastUpdated' => '1254902517',
    'message' => 'Er is een syntax fout opgetreden in het sjabloon %s, %s, %s. Corrigeer a.u.b.'
  },
  'template in clipboard' => {
    'lastUpdated' => '1254902529',
    'message' => 'Sjabloon in klembord'
  },
  'template in trash' => {
    'lastUpdated' => '1254902539',
    'message' => 'Sjabloon in prullenbak'
  },
  'template parsers' => {
    'lastUpdated' => '1222349721',
    'message' => 'Sjabloon Parsers'
  },
  'template parsers list body' => {
    'lastUpdated' => '1222349730',
    'message' => 'De volgende sjabloon parsers zijn ge&iuml;nstalleerd op deze site en kunnen worden aangezet voor gebruik.'
  },
  'template parsers list title' => {
    'lastUpdated' => '1222349739',
    'message' => 'Lijst van sjabloon parsers'
  },
  'template variable title' => {
    'lastUpdated' => '1151502260',
    'message' => 'Sjabloon variabelen'
  },
  'usePacked description' => {
    'lastUpdated' => '1242137872',
    'message' => 'Gebruik de ingepakte versie van dit sjabloon voor snellere downloads'
  },
  'usePacked label' => {
    'lastUpdated' => '1242137852',
    'message' => 'Gebruik ingepakt sjabloon'
  },
  'visited link color' => {
    'lastUpdated' => '1151502183',
    'message' => 'Kleur bezochte links'
  },
  'visited link color description' => {
    'lastUpdated' => '1151502163',
    'message' => 'De kleur van bezochte links op de pagina. De standaardkleur is paars.'
  },
  'warning default template' => {
    'lastUpdated' => '1222877016',
    'message' => 'U probeert een standaard sjabloon te bewerken. Veranderingen die aan dit sjabloon worden gemaakt kunnen verloren gaan bij het upgraden van WebGUI. Door het maken van een duplicaat van dit sjabloon kan dit niet gebeuren.'
  },
  'webgui.status' => {
    'lastUpdated' => '1166204328',
    'message' => 'De status van deze WebGUI versie: stabiel, beta, gamma, etc.'
  },
  'webgui.version' => {
    'lastUpdated' => '1151502198',
    'message' => 'De WebGUI versie waarop deze site draait.'
  }
}
;

1;

==> webgui_7.10.29.orig.tar.gz: WebGUI/lib/WebGUI/i18n/Dutch/Asset_Template.pm <==
package WebGUI::i18n::Dutch::Asset_Template;
use utf8;
our $I18N = {
  'Already attached!' => {
    'lastUpdated' => '1258548972',
    'message' => 'Dit staat al in de bijlage!'
  },
  'Configure' => {
    'lastUpdated' => '1297774726',
    'message' => 'Configureren'
  },
  'Configure Preview' => {
    'lastUpdated' => '1297774899',
    'message' => 'Configuratie voorbeeld'
  },
  'Fetch' => {
    'lastUpdated' => '1297774909',
    'message' => 'Ophalen'
  },
  'Fetch Variables' => {
    'lastUpdated' => '1297774920',
    'message' => 'Variabelen ophalen'
  },
  'Fetch Variables hoverHelp' => {
    'lastUpdated' => '1297774950',
    'message' => 'Probeer variablen te gokken van een url waar dit sjabloon gebruikt wordt.'
  },
  'No url!' => {
    'lastUpdated' => '1258535779',
    'message' => 'Geen URL!'
  },
  'Plain Text hoverHelp' => {
    'lastUpdated' => '1297775352',
    'message' => 'Wanneer Ja aangevinkt wordt, wordt er een platte tekst antwoord gegeven (dit kan nuttig zijn voor het bekijken van de ruwe uitvoer van het sjabloon). Anders wordt de uitvoer gerenderd als HTML.'
  },
  'Plain Text?' => {
    'lastUpdated' => '1297776449',
    'message' => 'Voorbeeld als platte tekst?'
  },
  'Preview' => {
    'lastUpdated' => '1297776455',
    'message' => 'Voorbeeld'
  },
  'URL' => {
    'lastUpdated' => '1297776460',
    'message' => 'URL'
  },
  'URL hoverHelp' => {
    'lastUpdated' => '1297776495',
    'message' => 'URL dat gebruikt wordt door de "Ophalen" knop.'
  },
  'Variables' => {
    'lastUpdated' => '1297776470',
    'message' => 'Variabelen'
  },
  'Variables hoverHelp' => {
    'lastUpdated' => '1297776520',
    'message' => 'Variabelen die gebruikt worden door de render knop.'
  },
  'assetName' => {
    'lastUpdated' => '1151504830',
    'message' => 'Sjabloon'
  },
  'attachment add button' => {
    'lastUpdated' => '1242729886',
    'message' => 'Toevoegen'
  },
  'attachment add field label' => {
    'lastUpdated' => '1242729965',
    'message' => 'Voeg bijlage(n) toe'
  },
  'attachment display label' => {
    'lastUpdated' => '1242729982',
    'message' => 'Bijlagen'
  },
  'attachment header index' => {
    'lastUpdated' => '1242730032',
    'message' => 'Reeksnummer'
  },
  'attachment header remove' => {
    'lastUpdated' => '1242730016',
    'message' => 'Verwijderen'
  },
  'attachment header type' => {
    'lastUpdated' => '1242730050',
    'message' => 'Type'
  },
  'attachment header url' => {
    'lastUpdated' => '1242730065',
    'message' => 'Url'
  },
  'body background color' => {
    'lastUpdated' => '1151506164',
    'message' => 'Achtergrondkleur body'
  },
  'body background color description' => {
    'lastUpdated' => '1207839342',
    'message' => 'De achtergrondkleur voor het body-gedeelte van de pagina.'
  },
  'body content' => {
    'lastUpdated' => '1151504950',
    'message' => 'Hier komt de content.'
  },
  'body text color' => {
    'lastUpdated' => '1151506183',
    'message' => 'Tekstkleur body'
  },
  'body text color description' => {
    'lastUpdated' => '1151652284',
    'message' => 'De kleur van de tekst in het body gedeelte.'
  },
  'choose a layout' => {
    'lastUpdated' => '1151506201',
    'message' => 'Kies een vormgeving voor deze stijl:'
  },
  'css label' => {
    'lastUpdated' => '1242730103',
    'message' => 'CSS Stylesheet'
  },
  'default parser' => {
    'lastUpdated' => '1166198514',
    'message' => 'Standaard parser'
  },
  'edit template' => {
    'lastUpdated' => '1151506214',
    'message' => 'Wijzigen sjabloon'
  },
  'field storageIdExample' => {
    'lastUpdated' => '1273488800',
    'message' => 'Voorbeeldafbeelding'
  },
  'field storageIdExample description' => {
    'lastUpdated' => '1273488844',
    'message' => 'Een voorbeeldafbeelding die toont hoe het sjabloon eruit ziet voordat het geselecteerd wordt door de gebruiker.'
  },
  'head block' => {
    'lastUpdated' => '1151654999',
    'message' => 'HEAD blok'
  },
  'head block description' => {
    'lastUpdated' => '1151655344',
    'message' => 'HEAD gedeelte van het HTML document. Hier komen de meta tags, style sheets, etc.'
  },
  'header background color' => {
    'lastUpdated' => '1151655022',
    'message' => 'Achtergrondkleur header'
  },
  'header background color description' => {
    'lastUpdated' => '1151655122',
    'message' => 'De achtergrondkleur van de header (het bovenste gedeelte) van de pagina.'
  },
  'header text color' => {
    'lastUpdated' => '1151655031',
    'message' => 'Tekstkleur header'
  },
  'header text color description' => {
    'lastUpdated' => '1151655131',
    'message' => 'De tekstkleur voor de header (het bovenste gedeelte) van de pagina.'
  },
  'heading' => {
    'lastUpdated' => '1151655169',
    'message' => 'Header'
  },
  'js body label' => {
    'lastUpdated' => '1242730148',
    'message' => 'Javascript (wordt ingevoegd net voor het </body> element)'
  },
  'js head label' => {
    'lastUpdated' => '1242730177',
    'message' => 'Javascript (wordt toegevoegd in de <head> sectie)'
  },
  'link color' => {
    'lastUpdated' => '1151505939',
    'message' => 'Link kleur'
  },
  'link color description' => {
    'lastUpdated' => '1151505973',
    'message' => 'De kleur van de links op de pagina. De standaardkleur is blauw.'
  },
  'logo' => {
    'lastUpdated' => '1151505728',
    'message' => 'Logo'
  },
  'logo description' => {
    'lastUpdated' => '1151505885',
    'message' => 'Dit veld kan gebruikt worden om een logo te uploaden. Het logo moet minder dan 200 pixels breed en minder dan 100 pixels hoog zijn.'
  },
  'logo subtext' => {
    'lastUpdated' => '1151505879',
    'message' => 'Het logo moet minder dan 200 pixels breed en minder dan 100 pixels hoog zijn.'
  },
  'make duplicate label' => {
    'lastUpdated' => '1222876939',
    'message' => 'Dupliceer dit sjabloon en bewerk'
  },
  'menu' => {
    'lastUpdated' => '1151505891',
    'message' => 'Menu'
  },
  'menu background color' => {
    'lastUpdated' => '1151505899',
    'message' => 'Achtergrondkleur menu'
  },
  'menu background color description' => {
    'lastUpdated' => '1208527745',
    'message' => 'De achtergrondkleur van het menu-gedeelte van de pagina.'
  },
  'namespace' => {
    'lastUpdated' => '1151506117',
    'message' => 'Namespace'
  },
  'namespace description' => {
    'lastUpdated' => '1151655217',
    'message' => 'Wat voor type sjabloon is dit?'
  },
  'page background color' => {
    'lastUpdated' => '1151506141',
    'message' => 'Achtergrondkleur pagina'
  },
  'page background color description' => {
    'lastUpdated' => '1151652299',
    'message' => 'De achtergrondkleur van de hele pagina.'
  },
  'parser' => {
    'lastUpdated' => '1151652326',
    'message' => 'Sjabloon type'
  },
  'parser description' => {
    'lastUpdated' => '1222349702',
    'message' => 'Wanneer in de configuratie meerdere mogelijke sjabloon engines zijn opgeven kunt u hier kiezen naar welke engines deze sjabloon moet worden gestuurd.'
  },
  'plugin enabled header' => {
    'lastUpdated' => '1166198534',
    'message' => 'Ingeschakeld?'
  },
  'plugin name' => {
    'lastUpdated' => '1166198541',
    'message' => 'Parser naam'
  },
  'session form variables' => {
    'lastUpdated' => '1151655244',
    'message' => '<p><strong>Sessie form variabelen</strong><br />Alle form variabelen zijn beschikbaar in het sjabloon m.b.v. de volgende syntax:<br />&lt;tmpl_var session.form.<em>variabele</em>&gt;<br />Indien de form&nbsp;variabele meer dan 1 waarde bevat zal enkel de laatste waarde worden doorgegeven.</p>'
  },
  'session scratch variables' => {
    'lastUpdated' => '1166204198',
    'message' => '<b>Sessie Scratch Variabelen</b><BR>
Alle scratchvariabelen zullen aanwezig zijn in het template volgens deze syntax:<BR>
&lt;tmpl_var session.scratch.<i>variabel</i>&gt;'
  },
  'session.config.extrasurl' => {
    'lastUpdated' => '1151505688',
    'message' => 'De URL van de extras directory uit de WebGUI configuratie.'
  },
  'session.setting.anonymousRegistration' => {
    'lastUpdated' => '1207830048',
    'message' => 'Mag een anonieme gebruiker wel of niet zich registreren op de site (uit de WebGUI instellingen).'
  },
  'session.setting.companyName' => {
    'lastUpdated' => '1151505612',
    'message' => 'De bedrijfsnaam uit de WebGUI instellingen.'
  },
  'session.user.firstDayOfWeek' => {
    'lastUpdated' => '1151505503',
    'message' => 'De eerste dag van de week zoals ingesteld in het gebruikersprofiel van de huidige gebruiker.'
  },
  'session.user.username' => {
    'lastUpdated' => '1207839306',
    'message' => 'De gebruikersnaam van de huidige gebruiker.'
  },
  'session.var.adminOn' => {
    'lastUpdated' => '1151505456',
    'message' => 'Deze variabele is waar indien de gebruiker in Admin mode is.'
  },
  'show in forms' => {
    'lastUpdated' => '1151505371',
    'message' => 'Zichtbaar in formulieren?'
  },
  'show in forms description' => {
    'lastUpdated' => '1168959904',
    'message' => 'Moet dit sjabloon zichtbaar zijn in de lijst van sjablonen uit deze namespace?'
  },
  'site name' => {
    'lastUpdated' => '1151504975',
    'message' => 'Sitenaam'
  },
  'site name description' => {
    'lastUpdated' => '1151504988',
    'message' => 'De naam van de website'
  },
  'style wizard' => {
    'lastUpdated' => '1151650653',
    'message' => 'Style&nbsp;wizard'
  },
  'template description' => {
    'lastUpdated' => '1151505077',
    'message' => 'Maak een sjabloon met behulp van sjabloon commando\'s, variabelen, macro\'s en HTML.'
  },
  'template error' => {
    'lastUpdated' => '1254902517',
    'message' => 'Er is een syntax fout opgetreden in het sjabloon %s, %s, %s. Corrigeer a.u.b.'
  },
  'template in clipboard' => {
    'lastUpdated' => '1254902529',
    'message' => 'Sjabloon in klembord'
  },
  'template in trash' => {
    'lastUpdated' => '1254902539',
    'message' => 'Sjabloon in prullenbak'
  },
  'template parsers' => {
    'lastUpdated' => '1222349721',
    'message' => 'Sjabloon Parsers'
  },
  'template parsers list body' => {
    'lastUpdated' => '1222349730',
    'message' => 'De volgende sjabloon parsers zijn ge&iuml;nstalleerd op deze site en kunnen worden aangezet voor gebruik.'
  },
  'template parsers list title' => {
    'lastUpdated' => '1222349739',
    'message' => 'Lijst van sjabloon parsers'
  },
  'template variable title' => {
    'lastUpdated' => '1151502260',
    'message' => 'Sjabloon variabelen'
  },
  'usePacked description' => {
    'lastUpdated' => '1242137872',
    'message' => 'Gebruik de ingepakte versie van dit sjabloon voor snellere downloads'
  },
  'usePacked label' => {
    'lastUpdated' => '1242137852',
    'message' => 'Gebruik ingepakt sjabloon'
  },
  'visited link color' => {
    'lastUpdated' => '1151502183',
    'message' => 'Kleur bezochte links'
  },
  'visited link color description' => {
    'lastUpdated' => '1151502163',
    'message' => 'De kleur van bezochte links op de pagina. De standaardkleur is paars.'
  },
  'warning default template' => {
    'lastUpdated' => '1222877016',
    'message' => 'U probeert een standaard sjabloon te bewerken. Veranderingen die aan dit sjabloon worden gemaakt kunnen verloren gaan bij het upgraden van WebGUI. Door het maken van een duplicaat van dit sjabloon kan dit niet gebeuren.'
  },
  'webgui.status' => {
    'lastUpdated' => '1166204328',
    'message' => 'De status van deze WebGUI versie: stabiel, beta, gamma, etc.'
  },
  'webgui.version' => {
    'lastUpdated' => '1151502198',
    'message' => 'De WebGUI versie waarop deze site draait.'
  }
}
;

1;
